Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(22)

Unified Diff: blimp/net/client_connection_manager.h

Issue 2281783002: Changes client_token to be client_auth_token. (Closed)
Patch Set: Linting. Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « blimp/engine/session/blimp_engine_session.cc ('k') | blimp/net/client_connection_manager.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: blimp/net/client_connection_manager.h
diff --git a/blimp/net/client_connection_manager.h b/blimp/net/client_connection_manager.h
index 5e3900614feb7fab45eed54ca520122e32385584..50f1b3747412ca2a6ec70baf102c7aeecfa4bb63 100644
--- a/blimp/net/client_connection_manager.h
+++ b/blimp/net/client_connection_manager.h
@@ -46,9 +46,9 @@ class BLIMP_NET_EXPORT ClientConnectionManager
// cases such as network switches, online/offline changes.
void Connect();
- // Sets the client token to use in the authentication message.
- void set_client_token(const std::string& client_token) {
- client_token_ = client_token;
+ // Sets the client auth token to use in the authentication message.
+ void set_client_auth_token(const std::string& client_auth_token) {
+ client_auth_token_ = client_auth_token;
}
private:
@@ -70,7 +70,7 @@ class BLIMP_NET_EXPORT ClientConnectionManager
// ConnectionErrorObserver implementation.
void OnConnectionError(int error) override;
- std::string client_token_;
+ std::string client_auth_token_;
ConnectionHandler* connection_handler_;
std::vector<std::unique_ptr<BlimpTransport>> transports_;
base::WeakPtrFactory<ClientConnectionManager> weak_factory_;
« no previous file with comments | « blimp/engine/session/blimp_engine_session.cc ('k') | blimp/net/client_connection_manager.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698